@@ -77,6 +77,11 @@ impl PhysFsHandle {
     pub fn close(self) {}
 }
 
+//PhysFs is supposed to manage concurrent access on its own 
+//through a global mutex so it should be thread safe
+unsafe impl Send for PhysFsHandle {}
+unsafe impl Sync for PhysFsHandle {}
+
 impl std::io::Read for PhysFsHandle {
     fn read(&mut self, buf: &mut [u8]) -> std::io::Result<usize> {
         Ok(unsafe {
